@@ -17,7 +17,7 @@ import getopt
 import socket
 import warnings
 
-from .utilities import PROXY_HEADERS
+from .proxy_headers import PROXY_HEADERS
 from .compat import (
     PY2,
     WIN,
@@ -27,7 +27,10 @@ from .compat import (
 
 truthy = frozenset(('t', 'true', 'y', 'yes', 'on', '1'))
 
-KNOWN_PROXY_HEADERS = {header.lower().replace('_', '-') for header in PROXY_HEADERS}
+KNOWN_PROXY_HEADERS = frozenset(
+    header.lower().replace('_', '-')
+    for header in PROXY_HEADERS
+)
 
 def asbool(s):
     """ Return the boolean value ``True`` if the case-lowered value of string
@@ -112,6 +115,7 @@ class Adjustments(object):
         ('recv_bytes', int),
         ('send_bytes', int),
         ('outbuf_overflow', int),
+        ('outbuf_high_watermark', int),
         ('inbuf_overflow', int),
         ('connection_limit', int),
         ('cleanup_interval', int),
@@ -195,17 +199,19 @@ class Adjustments(object):
     # recv_bytes is the argument to pass to socket.recv().
     recv_bytes = 8192
 
-    # send_bytes is the number of bytes to send to socket.send().  Multiples
-    # of 9000 should avoid partly-filled packets, but don't set this larger
-    # than the TCP write buffer size.  In Linux, /proc/sys/net/ipv4/tcp_wmem
-    # controls the minimum, default, and maximum sizes of TCP write buffers.
-    send_bytes = 18000
+    # deprecated setting controls how many bytes will be buffered before
+    # being flushed to the socket
+    send_bytes = 1
 
     # A tempfile should be created if the pending output is larger than
     # outbuf_overflow, which is measured in bytes. The default is 1MB.  This
     # is conservative.
     outbuf_overflow = 1048576
 
+    # The app_iter will pause when pending output is larger than this value
+    # in bytes.
+    outbuf_high_watermark = 16777216
+
     # A tempfile should be created if the pending input is larger than
     # inbuf_overflow, which is measured in bytes. The default is 512K.  This
     # is conservative.
@@ -289,6 +295,12 @@ class Adjustments(object):
         if 'unix_socket' in kw and 'listen' in kw:
             raise ValueError('unix_socket may not be set if listen is set')
 
+        if 'send_bytes' in kw:
+            warnings.warn(
+                'send_bytes will be removed in a future release',
+                DeprecationWarning,
+            )
+
         for k, v in kw.items():
             if k not in self._param_map:
                 raise ValueError('Unknown adjustment %r' % k)
